@@ -213,24 +213,24 @@ class AccessibleImpl (BaseProxy):
                 return self.acc_factory.create_application(self.app_name)
 
         def getAttributes(self):
-                func = self.get_dbus_method("getAttributes", dbus_interface=ATSPI_ACCESSIBLE)
+                func = self.get_dbus_method("GetAttributes", dbus_interface=ATSPI_ACCESSIBLE)
                 attr = func ()
                 return [key + ':' + value for key, value in attr.iteritems()]
 
         def getChildAtIndex(self, index):
-                count = Int32(self._pgetter(self.dbus_interface, "childCount"))
+                count = Int32(self._pgetter(self.dbus_interface, "ChildCount"))
                 if index >= count:
                         raise IndexError
-                func = self.get_dbus_method("getChildAtIndex", dbus_interface=ATSPI_ACCESSIBLE)
+                func = self.get_dbus_method("GetChildAtIndex", dbus_interface=ATSPI_ACCESSIBLE)
                 path = func (index)
                 return self.acc_factory.create_accessible(self._app_name, path, ATSPI_ACCESSIBLE)
 
         def getLocalizedRoleName(self):
-                func = self.get_dbus_method("getLocalizedRoleName", dbus_interface=ATSPI_ACCESSIBLE)
+                func = self.get_dbus_method("GetLocalizedRoleName", dbus_interface=ATSPI_ACCESSIBLE)
                 return func()
 
         def getRelationSet(self):
-                func = self.get_dbus_method("getRelationSet", dbus_interface=ATSPI_ACCESSIBLE)
+                func = self.get_dbus_method("GetRelationSet", dbus_interface=ATSPI_ACCESSIBLE)
                 relation_set = func()
                 return _marshal_relation_set(self.acc_factory, self._app_name, relation_set)
 
@@ -239,33 +239,33 @@ class AccessibleImpl (BaseProxy):
                 return func()
 
         def getRole(self):
-                func = self.get_dbus_method("getRole", dbus_interface=ATSPI_ACCESSIBLE)
+                func = self.get_dbus_method("GetRole", dbus_interface=ATSPI_ACCESSIBLE)
                 return func()
 
         def getRoleName(self):
-                func = self.get_dbus_method("getRole", dbus_interface=ATSPI_ACCESSIBLE)
+                func = self.get_dbus_method("GetRole", dbus_interface=ATSPI_ACCESSIBLE)
                 return ROLE_NAMES[func()]
 
         def getState(self):
-                func = self.get_dbus_method("getState", dbus_interface=ATSPI_ACCESSIBLE)
+                func = self.get_dbus_method("GetState", dbus_interface=ATSPI_ACCESSIBLE)
                 return _marshal_state_set(func())
 
         def get_childCount(self):
-                return Int32(self._pgetter(self.dbus_interface, "childCount"))
+                return Int32(self._pgetter(self.dbus_interface, "ChildCount"))
 
         def get_description(self):
-                return self._pgetter(self.dbus_interface, "description")
+                return self._pgetter(self.dbus_interface, "Description")
 
         def get_name(self):
-                return self._pgetter(self.dbus_interface, "name")
+                return self._pgetter(self.dbus_interface, "Name")
 
         def get_parent(self):
                 return self.acc_factory.create_accessible(self._app_name,
-                                                          self._pgetter (self.dbus_interface, "parent"),
+                                                          self._pgetter (self.dbus_interface, "Parent"),
                                                           ATSPI_ACCESSIBLE)
 
         def get_interfaces (self):
-                func = self.get_dbus_method("getInterfaces", dbus_interface=ATSPI_ACCESSIBLE)
+                func = self.get_dbus_method("GetInterfaces", dbus_interface=ATSPI_ACCESSIBLE)
                 return func()
 
 #------------------------------------------------------------------------------
@@ -287,14 +287,16 @@ class AccessibleImplCached (AccessibleImpl):
                 return self.cache(self.app_name, self.acc_path)
 
         def getChildAtIndex(self, index):
-                path = self.cached_data.children[index]
-                return self.acc_factory.create_accessible(self._app_name, path, ATSPI_ACCESSIBLE)
+                (name, path) = self.cached_data.children[index]
+                if (name == ""):
+                        name = self._app_name
+                return self.acc_factory.create_accessible(name, path, ATSPI_ACCESSIBLE)
 
         def getRelationSet(self):
                 if self._relation_set is not None:
                         return self._relation_set
                 else:
-                        func = self.get_dbus_method("getRelationSet", dbus_interface=ATSPI_ACCESSIBLE)
+                        func = self.get_dbus_method("GetRelationSet", dbus_interface=ATSPI_ACCESSIBLE)
                         relation_set = func()
                         self._relation_set = _marshal_relation_set(self.acc_factory, self._app_name, relation_set)
                         return self._relation_set
@@ -328,8 +330,11 @@ class AccessibleImplCached (AccessibleImpl):
                 return self.cached_data.name
 
         def get_parent(self):
-                return self.acc_factory.create_accessible(self._app_name,
-                                                          self.cached_data.parent,
+                [name, path] = self.cached_data.parent
+                if (name == ""):
+                        name = self._app_name
+                return self.acc_factory.create_accessible(name,
+                                                          path,
                                                           ATSPI_ACCESSIBLE)
 
         def get_interfaces (self):
